@@ -3,7 +3,7 @@
 # Build a changelog file for a CVS project
 # Serveral output format are available
 #-------------------------------------------------------
-# $Revision: 1.79 $ - $Author: eldy $ - $Date: 2006/11/17 01:12:42 $
+# $Revision: 1.83 $ - $Author: eldy $ - $Date: 2008/04/22 11:19:46 $
 use strict; no strict "refs";
 use Time::Local;
 use CGI qw/:standard/;
@@ -13,8 +13,8 @@ use CGI qw/:standard/;
 #-------------------------------------------------------
 # Defines
 #-------------------------------------------------------
-my $REVISION='$Revision: 1.79 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
-my $VERSION="2.3 (build $REVISION)";
+my $REVISION='$Revision: 1.83 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+my $VERSION="2.4 (build $REVISION)";
 
 # ---------- Init variables --------
 use vars qw/ $TagStart $Branch $TagEnd $Since /;
@@ -24,6 +24,8 @@ my $DIR;
 my $PROG;
 my $Extension;
 my $Help='';
+my $AllowIndex=0;
+my $IncludeHeader='';
 my $Module='';
 my $CacheNameForModule='';
 my $Output='';		# Default will be "listdeltabydate"
@@ -229,6 +231,17 @@ sub LoadDataInMemory {
 	$filelog =~ s/^\s*[\r\n]*//g;				# Remove starting blank
 	my $newfilelog=ucfirst("$filelog");
 
+	# If log start with "file .cvsignore was initially added on branch xxx"
+	# It is an add in branch xxx
+	if ($filelog =~ /file (.*) was initially added on branch (.*)/i)
+	{
+		if (! $Branch || (uc($Branch) != uc($2)))
+		{
+			debug(" Entry discarded because in branch $2",2);
+			return;
+		}
+	}
+	
 	# DEFINE CHANGE STATUS (removed, changed or added) OF FILE
 	my $newfilestate='';
 	if ($Output =~ /^listdelta/ || $Output =~ /^buildhtmlreport/) {
@@ -534,7 +547,7 @@ sub FormatCvsFileLink {
         $string =~ s/__MODULE__/$Module/g;
         $url =~ s/$Module\@//g;
         $string.="$url";
-        $string.="?rev=".$version;
+        $string.="?view=markup&rev=".$version;
     	return "<a href=\"$string\" target=\"_newcvs\">$url</a>";
 	}
 	else {
@@ -699,6 +712,8 @@ if ($QueryString =~ /-d=([^\s]+)/)      		{ $CvsRoot=$1; }
 if ($QueryString =~ /-h/)      					{ $Help=1; }
 if ($QueryString =~ /-ignore=([^\s]+)/i)        { map { $IgnoreFileDir{quotemeta($_)}=1; } split(',',$1); }
 if ($QueryString =~ /-only=([^\s]+)/i)        	{ $OnlyFileDir{$1}=1; }
+if ($QueryString =~ /-allowindex/i) 		  	{ $AllowIndex=1; }
+if ($QueryString =~ /-includeheader=([^\s]+)/i) { $IncludeHeader=$1; }
 ($DIR=$0) =~ s/([^\/\\]+)$//; ($PROG=$1) =~ s/\.([^\.]*)$//; $Extension=$1;
 $DIR||='.'; $DIR =~ s/([^\/\\])[\\\/]+$/$1/;
 debug("Parameter Module       : $Module");
@@ -707,6 +722,7 @@ debug("Parameter OutputDir    : $OutputDir");
 debug("Parameter Branch       : $Branch");
 debug("Parameter ViewCvsUrl   : $ViewCvsUrl");
 debug("Parameter Since        : $Since");
+debug("Parameter Debug        : $Debug");
 debug("Parameter IgnoreFileDir: ".join(',',keys %IgnoreFileDir));
 if ($ViewCvsUrl && $ViewCvsUrl !~ /\/$/) { $ViewCvsUrl.="/"; }
 
@@ -786,7 +802,9 @@ if ($Help || ! $Output)
 	writeoutput("                           will be replaced by name of CVS module.\n");
 	writeoutput("  -ignore=file/dir    To exclude a file/dir off report.\n");
 	writeoutput("  -only=file/dir      To have reports only on file/dir that match.\n");
-	writeoutput("  -debug=x            To output on stderr some debug info with level x\n");
+	writeoutput("  -includeheader=file To add content of a file after body tag.\n");
+	writeoutput("  -allowindex         To allow meta tag index (noindex by default).\n");
+	writeoutput("  -debug=x            To output on stderr some debug info with level x.\n");
 	writeoutput("\n");
 	writeoutput("Examples:\n");
 	writeoutput("  $PROG.$Extension -output=listdeltabyfile -module=myproject -tagstart=myproj_2_0 -d=john\@cvsserver:/cvsdir\n");
@@ -1257,10 +1275,10 @@ if ($Output !~ /buildhtmlreport$/) {
 else {
     writeoutputfile "<html>\n<head>\n";
     writeoutputfile "<meta name=\"generator\" content=\"$PROG $VERSION\" />\n";
-    writeoutputfile "<meta name=\"robots\" content=\"noindex,nofollow\" />\n";
+    writeoutputfile "<meta name=\"robots\" content=\"".($AllowIndex?"":"no")."index,".($AllowIndex?"":"no")."follow\" />\n";
     writeoutputfile "<meta http-equiv=\"content-type\" content=\"text/html; charset=iso-8859-1\" />\n";
-    writeoutputfile "<meta http-equiv=\"description\" content=\"$headstring\" />\n";
-    writeoutputfile "<title>CVS report for $Module</title>\n";
+    writeoutputfile "<meta http-equiv=\"description\" content=\"CVS Report for development activity on module $Module - Built by CVSChangeLogBuilder\" />\n";
+    writeoutputfile "<title>CVS report for activity on module $Module</title>\n";
     writeoutputfile <<EOF;
 <style type="text/css">
 <!--
@@ -1295,6 +1313,15 @@ div { font: 12px 'Arial','Verdana','Helvetica', sans-serif; text-align: justify;
 EOF
     writeoutputfile "</head>\n";
     writeoutputfile "<body>\n";
+	if ($IncludeHeader)
+	{
+		open(INCLUDE,"<$IncludeHeader") || die "Failed to open includeheader $IncludeHeader file";
+		my $line='';
+		while ($line=<INCLUDE>) {
+			writeoutputfile $line;
+		}
+        close(INCLUDE);		
+	}
 }
 
 # For output by date
